#!/bin/bash
# Copyright start
# Copyright (C) 2008 - 2023 Fortinet Inc.
# All rights reserved.
# FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
# Copyright end

generate_cert() {
    #
    # Generate PKCS12 tomcat server keystore. This will be present by Tomcat server to the client.
    # The keystore password mentioned here is used in server.xml in tomcat. If you change
    # here, make sure to change in server.xml checked in in tomcats git repo.
    #
    local tomcat_server_keystore="/opt/cyops-tomcat/conf/server_keystore.p12"
    if [ -f "$tomcat_server_keystore" ]; then
        return
    fi
    local cert_dir="/etc/pki/cyops"
    local fsr_default_cert="$cert_dir/server.leaf.crt"
    local fsr_default_key="$cert_dir/server.leaf.key"
    local fsr_default_root_ca="/etc/pki/ca-trust/source/anchors/cs.loc.root.crt"
    echo "Generating $tomcat_server_keystore"
    openssl pkcs12 -export -out $tomcat_server_keystore \
                           -in $fsr_default_cert \
                           -inkey $fsr_default_key \
                           -CAfile $fsr_default_root_ca \
                           -caname fortioar.localhost \
                           -chain \
                           -name 'tomcat' \
                           -passout pass:1eENUcjkIYovX9t6
    if [ $? -ne 0 ]; then
        echo "Failed to generate tomcat certificate"
        exit 1
    fi
    chmod 644 $tomcat_server_keystore
    echo "Restarting tomcat"
    systemctl restart cyops-tomcat
}

configure_tomcat() {
    generate_cert
    sed -i "s#http://localhost:8080#https://localhost:8444#g" /opt/cyops-api/config/parameters_prod.yaml
    sed -i "s#proxy_pass http://localhost:8080/notifier#proxy_pass https://localhost:8444/notifier#g" /etc/nginx/conf.d/cyops-api.conf
}

############
# Main/main/MAIN starts here
#########
configure_tomcat
exit 0
